EXTRA_COLORS = {
    "paper:bg": "#eeeeee",
    "paper:fg": "#444444",
    "paper:bgAlt": "#e4e4e4",
    "paper:red": "#af0000",
    "paper:green": "#008700",
    "paper:blue": "#005f87",
    "paper:yellow": "#afaf00",
    "paper:orange": "#d75f00",
    "paper:pink": "#d70087",
    "paper:purple": "#8700af",
    "paper:lightBlue": "#0087af",
    "paper:olive": "#5f7800",
    "on:bg": "#1b2b34",
    "on:fg": "#cdd3de",
    "on:bgAlt": "#343d46",
    "on:fgAlt": "#d8dee9",
    "on:red": "#ec5f67",
    "on:orange": "#f99157",
    "on:yellow": "#fac863",
    "on:green": "#99c794",
    "on:cyan": "#5fb3b3",
    "on:blue": "#6699cc",
    "on:pink": "#c594c5",
    "on:brown": "#ab7967",
    "series:cyan": "#54c9d1",
    "series:orange": "#eca89a",
    "series:blue": "#95bced",
    "series:olive": "#ceb776",
    "series:purple": "#d3a9ea",
    "series:green": "#9bc57f",
    "series:pink": "#f0a1ca",
    "series:turquoise": "#5fcbaa",
    "atlas:onesigma": "#00ff26",
    "atlas:twosigma": "#fbff1f",
    "series2:green": "#00ff26",
    "series2:yellow": "#fbff1f",
    "series2:blue": "#00a1e0",
    "series2:red": "#a30013",
    "series2:purple": "#5100c2",
    "hdbs:starcommandblue": "#047cbc",
    "hdbs:spacecadet": "#283044",
    "hdbs:mintcream": "#ebf5ee",
    "hdbs:outrageousorange": "#fa7e61",
    "hdbs:pictorialcarmine": "#ca1551",
    "hdbs:maroonX11": "#b8336a",
    "hh:darkpink": "#f2385a",
    "hh:darkblue": "#343844",
    "hh:medturquoise": "#36b1bf",
    "hh:lightturquoise": "#4ad9d9",
    "hh:offwhite": "#e9f1df",
    "hh:darkyellow": "#fdc536",
    "hh:darkgreen": "#125125",
    "transparent": "#ffffff00",
}

QUICKSTATS_PALETTES  = dict(
    darklines=["#000000", "#0019f5", "#377d22", "#ea3423", "#f2a93b", "#7f170e"],
    default=['#000000', '#F2385A', '#4AD9D9', '#FDC536', '#125125', '#E88EED', '#B68D40'],
    hist_series=['#99CCFF', '#EFCF6E', '#64CB34'],
    shading_light=["#FBF0D9", "#C0E7DC", "#E4C0F4", "#B3D4E8"],
    shading_medium=["#E0DCC5", "#C5E00C", "#E0C5D4", "#C5C5E0"],
    shading_dark=["#C1B98A", "#8AC199", "#C18AA9", "#8B8AC1"],
    ibm=["#648fff", "#785ef0", "#dc267f", "#fe6100", "#ffb000"],
    butterflycore=["#f4cccc", "#ffe599", "#b6d7a8", "#9fc5e8", "#9C98DB", "#D6BFAB", "#876659"],
    simple_contrast=["#ED553B", "#20639B", "#3CAEA3", "#F6D55C", "#BF51A0", "#735245"],
    checker=["#068EAC", "#DE5B7D", "#4A9451", "#F97623", "#FAE215", "#BF51A0",
             "#84E4D0", "#B32A32", "#ADE85B", "#FFA41A", "#505BB6", "#596D3D",
             "#2C388E", "#5B3F7B", "#8D89C2", "#6586B3", "#CCA18D", "#735245"]
)